get_profile

Function get_profile 

pub(crate) async fn get_profile(
    client: Client,
    mxid: &UserId,
) -> Result<UserProfile>
This function calls the GET profile endpoint Spec: https://spec.matrix.org/latest/client-server-api/#get_matrixclientv3profileuserid Ruma: https://docs.rs/ruma-client-api/latest/ruma_client_api/profile/get_profile/v3/index.html The Matrix spec does not require authentication for this endpoint. However, some server configurations (e.g. Synapse’s require_auth_for_profile_requests) enforce auth to prevent user enumeration, which will cause client.send() to return a 401 error.